@@ -42,8 +42,7 @@ kmBlockC<-function(M,
   diagonal<-match.arg(diagonal)
   limitType<-match.arg(limitType)  
   if(is.null(weights)){
-    weights<-M
-    weights[,]<-1
+    weights <- array(1, dim(M))
   } else if(any(dim(weights)!=dim(M))) stop("Weights have wrong dim!")
   w<-weights
 
@@ -168,8 +167,7 @@ critFunKmeans<-function(M,
   diagonal<-match.arg(diagonal)
   limitType<-match.arg(limitType)  
   if(is.null(weights)){
-    weights<-M
-    weights[]<-1
+    weights<- array(1, dim = dim(M))
   } else if(any(dim(weights)!=dim(M))) stop("Weights have wrong dim!")
   w<-weights
   
@@ -271,10 +269,10 @@ critFunKmeans<-function(M,
 #' @param return.all If \code{FALSE}, solution for only the best (one or more) partition/s is/are returned.
 #' @param return.err Should the error for each optimized partition be returned. Defaults to \code{TRUE}.
 #' @param seed Optional. The seed for random generation of partitions.
-#' @param parGenFun The function (object) that will generate random partitions. The default function is   \code{\link{genRandomPar}}. The function has to accept the following parameters: \code{k} (number o of partitions by modes, \code{n} (number of units by modes), \code{seed} (seed value for random generation of partition), \code{addParam} (a list of additional parameters).
+#' @param parGenFun The function (object) that will generate random partitions. The default function is \code{\link[blockmodeling]{genRandomPar}}. The function has to accept the following parameters: \code{k} (number o of partitions by modes, \code{n} (number of units by modes), \code{seed} (seed value for random generation of partition), \code{addParam} (a list of additional parameters).
 #' @param mingr Minimal allowed group size.
 #' @param maxgr Maximal allowed group size.
-#' @param addParam A list of additional parameters for function specified above. In the usage section they are specified for the default function \code{\link{genRandomPar}}.
+#' @param addParam A list of additional parameters for function specified above. In the usage section they are specified for the default function \code{\link[blockmodeling]{genRandomPar}}.
 #' @param maxTriesToFindNewPar The maximum number of partition try when trying to find a new partition to optimize that was not yet checked before - the default value is \code{rep * 1000}.
 #' @param skip.par The partitions that are not allowed or were already checked and should therefore be skipped.
 #' @param printRep Should some information about each optimization be printed.
@@ -364,7 +362,7 @@ kmBlockORPC<-function(M, #a square matrix
                          parGenFun = blockmodeling::genRandomPar, #The function that will generate random partitions. It should accept argumetns: k (number of partitions by modes, n (number of units by modes), seed (seed value for random generation of partition), addParam (a list of additional parametres)
                          mingr=NULL, #minimal alowed group size (defaults to c(minUnitsRowCluster,minUnitsColCluster) if set, else to 1) - only used for parGenFun function 
                          maxgr=NULL, #maximal alowed group size (default to c(maxUnitsRowCluster,maxUnitsColCluster) if set, else to Inf) - only used for parGenFun function 
-                         addParam=list(  #list of additional parameters for gerenrating partitions. Here they are specified for dthe default function "genRandomPar"
+                         addParam=list(  #list of additional parameters for gerenrating partitions. Here they are specified for the default function "genRandomPar"
                            genPajekPar = TRUE,     #Should the partitions be generated as in Pajek (the other options is completly random)
                            probGenMech = NULL),    #Here the probabilities for different mechanizems for specifying the partitions are set. If not set this is determined based on the previous parameter.
                          maxTriesToFindNewPar=rep*10,    #The maximum number of partition try when trying to find a new partition to optimize that was not yet checked before 
